==> fis3-deploy-staticsource-1.0.0.tgz: package/index.js <==
/*
 * 
 */
'use strict';
var _ = require('../fis3/lib/util.js');
var crypto = require('crypto'); //引入加密插件
var archiver = require('archiver'); //引入node压缩插件

module.exports = function(content, file, settings) {
	var sourceDate = {
		zip: {},
		source: [],
		domain: []
	}; //当前资源

	var zipSource = []; //文件压缩时需要的数据
	var releasePath = content.path + '/config/appCache.json'; //总资源路径
	var urlFileDir = content.urlFileDir; //输出根目录下输出项目文件夹
	var folder = namespace(file[0].dirname); //单个项目文件夹
	var oldData = fileData(releasePath); //上一次release资源表
	var data = fileData(content.path + content.packPath); //获取map.json内容
	var sourceDomin = ''; //url自带第一域名
	var oldSource = JSON.stringify(oldData.source); //定义变量位置不能后移

	//获取含有hash文件名
	function getFileName(url) {
		return url.substring(url.lastIndexOf("/") + 1);
	}

	//获取文件内容
	function fileData(filePath) {
		try {
			var fileData = _.fs.readFileSync(filePath);
			return JSON.parse(fileData.toString());
		} catch (exp) {
			return false;
		}
	}

	//删除url中domain
	function deleteDomain(url) {
		return url.substring(url.indexOf(content.urlFileDir));
	}

	//文件路径加命名空间
	function pathHasfile(fileUri) {
		if (/\:/.test(fileUri)) {
			return fileUri;
		} else {
			return folder + ':' + fileUri;
		}
	}

	//获取文件大小
	function getSize(uri) {
		uri = content.path + '/' + uri.substring(uri.lastIndexOf(folder + '/'));
		return _.fs.statSync(uri).size;
	}

	//获取文件路径，获得domin变量
	function getPath(url) {
		url = url.substring(url.lastIndexOf(urlFileDir + '/') + urlFileDir.length + 1);
		url = content.path + '/' + url;
		return url;
	}

	//获取命名空间
	function namespace(path) {
		path = path.substring(path.lastIndexOf('/') + 1);
		return path;
	}

	//判断是否存在上一文件输出资源
	if (oldData) {
		sourceDate.source = oldData.source;
		for (var i = 0; i < sourceDate.source.length; i++) {
			if (sourceDate.source[i].folder == folder) {
				sourceDate.source.splice(i, 1);
				i--;
			}
		}
	}

	//资源内容写入
	for (var i = 0; i < content.fileName.length; i++) {
		var mapKey = pathHasfile(content.fileName[i]);
		var itemUrl = '';
		var itemHas = false;
		if (data.res[mapKey].pkg) {
			itemUrl = data.pkg[data.res[mapKey].pkg].uri;
		} else {
			itemUrl = data.res[mapKey].uri;
		}

		if (sourceDomin == '') {
			sourceDomin = itemUrl.substring(0, itemUrl.indexOf(urlFileDir))
		};

		for (var n = 0; n < sourceDate.source.length; n++) {
			if (sourceDate.source[n].url == deleteDomain(itemUrl)) {
				itemHas = true;
			}
		}

		if (!itemHas) {
			sourceDate.source.push({
				"url": deleteDomain(itemUrl),
				"folder": folder,
				"size": getSize(itemUrl),
				"fileName": getFileName(itemUrl)
			})
		}
	}

	//判断资源是否需要重新打包、输出json列表
	if (oldSource != JSON.stringify(sourceDate.source) || typeof oldSource == undefined) {
		//输出打包资源
		for (var i = 0; i < sourceDate.source.length; i++) {
			var pushData = {
				name: sourceDate.source[i].fileName,
				path: getPath(sourceDate.source[i].url)
			};
			zipSource.push(pushData);
		}

		//打包过程开始
		var zipHash = JSON.stringify(zipSource);
		var hash = crypto.createHash('md5');
		hash.update(zipHash);
		zipHash = hash.digest('hex');
		zipHash = '_' + zipHash.substring(zipHash.length - 7);

		//zip包地址
		var zipTruePath = '/appCache/appCache' + zipHash + '.zip';
		var zipPath = content.path + zipTruePath;

		//新建缓存文件夹
		try {
			_.fs.mkdirSync(content.path + '/appCache/');
		} catch (exp) {}

		//创建一最终打包文件的输出流
		var output = _.fs.createWriteStream(zipPath);
		//生成archiver对象，打包类型为zip
		var zipArchiver = archiver('zip');

		//将打包对象与输出流关联
		zipArchiver.pipe(output);

		for (var i = 0; i < zipSource.length; i++) {
			//将被打包文件的流添加进archiver对象中
			zipArchiver.append(_.fs.createReadStream(zipSource[i].path), {
				'name': zipSource[i].name
			});
		}

		//打包
		zipArchiver.finalize();
		//由于同步操作,打包时间偏长,增加文件操作延迟时间
		setTimeout(function() {
			var zipSize = _.fs.statSync(zipPath).size;

			//压缩文件大小判断
			if (zipSize >= 512000) {
				throw new Error("压缩文件内容超过500KB");
				return
			}

			sourceDate.zip = {
				url: content.urlFileDir + zipTruePath,
				size: zipSize,
				fileName: getFileName(zipPath)
			}

			content.domain.unshift(sourceDomin);
			sourceDate.domain = content.domain;

			//文件写入
			_.fs.writeFile(releasePath, JSON.stringify(sourceDate), function(err) {
				if (err) {
					console.error(err);
				}
			});
		}, 1500);
	}
}

==> fis3-deploy-staticsource-1.0.2.tgz: package/index.js <==
/*
 * 
 */
'use strict';
var _ = require('../fis3/lib/util.js');
var crypto = require('crypto'); //引入加密插件
var archiver = require('archiver'); //引入node压缩插件

module.exports = function(content, file, settings) {

	var sourceDate = {
		zip: {},
		source: [],
		domain: []
	}; //当前资源

	var zipSource = []; //文件压缩时需要的数据
	var releasePath = content.path + '/config/appCache.json'; //总资源路径
	var urlFileDir = content.urlFileDir; //输出根目录下输出项目文件夹
	var folder = namespace(file[0].dirname); //单个项目文件夹
	var oldData = fileData(releasePath); //上一次release资源表
	var data = fileData(content.path + content.packPath); //获取map.json内容
	var sourceDomin = ''; //url自带第一域名
	var oldSource = JSON.stringify(oldData.source); //定义变量位置不能后移

	//获取含有带路径hash文件名
	function getFileName(url) {
		return deleteDomain(url.replace(/(\:)|(\/)/ig, '_'));
	}

	//获取含有hash文件名
	function getOnlyFileName(url) {
		return url.substring(url.lastIndexOf("/") + 1);
	}

	//获取文件内容
	function fileData(filePath) {
		try {
			var fileData = _.fs.readFileSync(filePath);
			return JSON.parse(fileData.toString());
		} catch (exp) {
			return false;
		}
	}

	//删除url中domain
	function deleteDomain(url) {
		return url.substring(url.indexOf(content.urlFileDir));
	}

	//文件路径加命名空间
	function pathHasfile(fileUri) {
		if (/\:/.test(fileUri)) {
			return fileUri;
		} else {
			return folder + ':' + fileUri;
		}
	}

	//获取文件大小
	function getSize(url) {
		url = content.path + '/' + url.substring(url.lastIndexOf(folder + '/'));
		return _.fs.statSync(url).size;
	}

	//获取文件路径，获得domin变量
	function getPath(url) {
		url = url.substring(url.lastIndexOf(urlFileDir + '/') + urlFileDir.length + 1);
		url = content.path + '/' + url;
		return url;
	}

	//获取命名空间
	function namespace(path) {
		path = path.substring(path.lastIndexOf('/') + 1);
		return path;
	}

	//判断是否存在上一文件输出资源
	if (oldData) {
		sourceDate.source = oldData.source;
		for (var i = 0; i < sourceDate.source.length; i++) {
			if (sourceDate.source[i].folder == folder) {
				sourceDate.source.splice(i, 1);
				i--;
			}
		}
	}

	//资源内容写入
	for (var i = 0; i < content.fileName.length; i++) {
		var mapKey = pathHasfile(content.fileName[i]);
		var itemUrl = '';
		var itemHas = false;
		if (data.res[mapKey].pkg) {
			itemUrl = data.pkg[data.res[mapKey].pkg].uri;
		} else {
			itemUrl = data.res[mapKey].uri;
		}

		if (sourceDomin == '') {
			sourceDomin = itemUrl.substring(0, itemUrl.indexOf(urlFileDir))
		};

		for (var n = 0; n < sourceDate.source.length; n++) {
			if (sourceDate.source[n].url == deleteDomain(itemUrl)) {
				itemHas = true;
			}
		}

		if (!itemHas) {
			sourceDate.source.push({
				"url": deleteDomain(itemUrl),
				"folder": folder,
				"size": getSize(itemUrl),
				"fileName": getFileName(itemUrl)
			})
		}
	}

	//判断资源是否需要重新打包、输出json列表
	if (oldSource != JSON.stringify(sourceDate.source) || typeof oldSource == undefined) {
		//输出打包资源
		for (var i = 0; i < sourceDate.source.length; i++) {
			var pushData = {
				name: sourceDate.source[i].fileName,
				path: getPath(sourceDate.source[i].url)
			};
			zipSource.push(pushData);
		}

		//打包过程开始
		var zipHash = JSON.stringify(zipSource);
		var hash = crypto.createHash('md5');
		hash.update(zipHash);
		zipHash = hash.digest('hex');
		zipHash = '_' + zipHash.substring(zipHash.length - 7);

		//zip包地址
		var zipTruePath = '/appCache/appCache' + zipHash + '.zip';
		var zipPath = content.path + zipTruePath;

		//新建缓存文件夹
		try {
			_.fs.mkdirSync(content.path + '/appCache/');
		} catch (exp) {}

		//创建一最终打包文件的输出流
		var output = _.fs.createWriteStream(zipPath);
		//生成archiver对象，打包类型为zip
		var zipArchiver = archiver('zip');

		//将打包对象与输出流关联
		zipArchiver.pipe(output);

		for (var i = 0; i < zipSource.length; i++) {
			//将被打包文件的流添加进archiver对象中
			zipArchiver.append(_.fs.createReadStream(zipSource[i].path), {
				'name': zipSource[i].name
			});
		}

		//打包
		zipArchiver.finalize();

		//zip完成检测
		output.on('close', function() {
			var zipSize = _.fs.statSync(zipPath).size;

			//压缩文件大小判断
			if (zipSize >= 512000) {
				throw new Error("压缩文件内容超过500KB");
				return
			}

			sourceDate.zip = {
				url: content.urlFileDir + zipTruePath,
				size: zipSize,
				fileName: getOnlyFileName(zipPath)
			}

			content.domain.unshift(sourceDomin);
			sourceDate.domain = content.domain;

			//文件写入
			_.fs.writeFile(releasePath, JSON.stringify(sourceDate), function(err) {
				if (err) {
					console.error(err);
				}
			});
		});
	}
}
